==> finclear-ibroker-proto-0.0.7-sources.jar: io/fincleartech/protobuf/ibroker/subscribe/IBrokerSubscribeServiceGrpc.java <==
package io.fincleartech.protobuf.ibroker.subscribe;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.22.1)",
    comments = "Source: fincleartech/ibroker/subscribe.proto")
public final class IBrokerSubscribeServiceGrpc {

  private IBrokerSubscribeServiceGrpc() {}

  public static final String SERVICE_NAME = "fincleartech.ibroker.IBrokerSubscribeService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge,
      io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> getSubscribeMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Subscribe",
      requestType = io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge.class,
      responseType = io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage.class,
      methodType = io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge,
      io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> getSubscribeMethod() {
    io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge, io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> getSubscribeMethod;
    if ((getSubscribeMethod = IBrokerSubscribeServiceGrpc.getSubscribeMethod) == null) {
      synchronized (IBrokerSubscribeServiceGrpc.class) {
        if ((getSubscribeMethod = IBrokerSubscribeServiceGrpc.getSubscribeMethod) == null) {
          IBrokerSubscribeServiceGrpc.getSubscribeMethod = getSubscribeMethod = 
              io.grpc.MethodDescriptor.<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge, io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(
                  "fincleartech.ibroker.IBrokerSubscribeService", "Subscribe"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage.getDefaultInstance()))
                  .setSchemaDescriptor(new IBrokerSubscribeServiceMethodDescriptorSupplier("Subscribe"))
                  .build();
          }
        }
     }
     return getSubscribeMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static IBrokerSubscribeServiceStub newStub(io.grpc.Channel channel) {
    return new IBrokerSubscribeServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static IBrokerSubscribeServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new IBrokerSubscribeServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static IBrokerSubscribeServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new IBrokerSubscribeServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class IBrokerSubscribeServiceImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Asynchronous persistent subscription to IBroker notifications.
     * </pre>
     */
    public io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge> subscribe(
        io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> responseObserver) {
      return asyncUnimplementedStreamingCall(getSubscribeMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSubscribeMethod(),
            asyncBidiStreamingCall(
              new MethodHandlers<
                io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge,
                io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage>(
                  this, METHODID_SUBSCRIBE)))
          .build();
    }
  }

  /**
   */
  public static final class IBrokerSubscribeServiceStub extends io.grpc.stub.AbstractStub<IBrokerSubscribeServiceStub> {
    private IBrokerSubscribeServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerSubscribeServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerSubscribeServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerSubscribeServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * Asynchronous persistent subscription to IBroker notifications.
     * </pre>
     */
    public io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge> subscribe(
        io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> responseObserver) {
      return asyncBidiStreamingCall(
          getChannel().newCall(getSubscribeMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class IBrokerSubscribeServiceBlockingStub extends io.grpc.stub.AbstractStub<IBrokerSubscribeServiceBlockingStub> {
    private IBrokerSubscribeServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerSubscribeServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerSubscribeServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerSubscribeServiceBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class IBrokerSubscribeServiceFutureStub extends io.grpc.stub.AbstractStub<IBrokerSubscribeServiceFutureStub> {
    private IBrokerSubscribeServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerSubscribeServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerSubscribeServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerSubscribeServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SUBSCRIBE = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final IBrokerSubscribeServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(IBrokerSubscribeServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBSCRIBE:
          return (io.grpc.stub.StreamObserver<Req>) serviceImpl.subscribe(
              (io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class IBrokerSubscribeServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    IBrokerSubscribeServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return io.fincleartech.protobuf.ibroker.subscribe.Subscribe.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("IBrokerSubscribeService");
    }
  }

  private static final class IBrokerSubscribeServiceFileDescriptorSupplier
      extends IBrokerSubscribeServiceBaseDescriptorSupplier {
    IBrokerSubscribeServiceFileDescriptorSupplier() {}
  }

  private static final class IBrokerSubscribeServiceMethodDescriptorSupplier
      extends IBrokerSubscribeServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    IBrokerSubscribeServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (IBrokerSubscribeServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new IBrokerSubscribeServiceFileDescriptorSupplier())
              .addMethod(getSubscribeMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> finclear-ibroker-proto-0.1.9-sources.jar: io/fincleartech/protobuf/ibroker/subscribe/IBrokerSubscribeServiceGrpc.java <==
package io.fincleartech.protobuf.ibroker.subscribe;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.23.0)",
    comments = "Source: fincleartech/ibroker/subscribe.proto")
public final class IBrokerSubscribeServiceGrpc {

  private IBrokerSubscribeServiceGrpc() {}

  public static final String SERVICE_NAME = "fincleartech.ibroker.IBrokerSubscribeService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge,
      io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> getSubscribeMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Subscribe",
      requestType = io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge.class,
      responseType = io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage.class,
      methodType = io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge,
      io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> getSubscribeMethod() {
    io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge, io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> getSubscribeMethod;
    if ((getSubscribeMethod = IBrokerSubscribeServiceGrpc.getSubscribeMethod) == null) {
      synchronized (IBrokerSubscribeServiceGrpc.class) {
        if ((getSubscribeMethod = IBrokerSubscribeServiceGrpc.getSubscribeMethod) == null) {
          IBrokerSubscribeServiceGrpc.getSubscribeMethod = getSubscribeMethod =
              io.grpc.MethodDescriptor.<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge, io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Subscribe"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage.getDefaultInstance()))
              .setSchemaDescriptor(new IBrokerSubscribeServiceMethodDescriptorSupplier("Subscribe"))
              .build();
        }
      }
    }
    return getSubscribeMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static IBrokerSubscribeServiceStub newStub(io.grpc.Channel channel) {
    return new IBrokerSubscribeServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static IBrokerSubscribeServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new IBrokerSubscribeServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static IBrokerSubscribeServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new IBrokerSubscribeServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class IBrokerSubscribeServiceImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Asynchronous persistent subscription to IBroker notifications.
     * </pre>
     */
    public io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge> subscribe(
        io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> responseObserver) {
      return asyncUnimplementedStreamingCall(getSubscribeMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getSubscribeMethod(),
            asyncBidiStreamingCall(
              new MethodHandlers<
                io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge,
                io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage>(
                  this, METHODID_SUBSCRIBE)))
          .build();
    }
  }

  /**
   */
  public static final class IBrokerSubscribeServiceStub extends io.grpc.stub.AbstractStub<IBrokerSubscribeServiceStub> {
    private IBrokerSubscribeServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerSubscribeServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerSubscribeServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerSubscribeServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * Asynchronous persistent subscription to IBroker notifications.
     * </pre>
     */
    public io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerAcknowledge> subscribe(
        io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage> responseObserver) {
      return asyncBidiStreamingCall(
          getChannel().newCall(getSubscribeMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class IBrokerSubscribeServiceBlockingStub extends io.grpc.stub.AbstractStub<IBrokerSubscribeServiceBlockingStub> {
    private IBrokerSubscribeServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerSubscribeServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerSubscribeServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerSubscribeServiceBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class IBrokerSubscribeServiceFutureStub extends io.grpc.stub.AbstractStub<IBrokerSubscribeServiceFutureStub> {
    private IBrokerSubscribeServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerSubscribeServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerSubscribeServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerSubscribeServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_SUBSCRIBE = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final IBrokerSubscribeServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(IBrokerSubscribeServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_SUBSCRIBE:
          return (io.grpc.stub.StreamObserver<Req>) serviceImpl.subscribe(
              (io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.subscribe.IBrokerMessage>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class IBrokerSubscribeServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    IBrokerSubscribeServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return io.fincleartech.protobuf.ibroker.subscribe.Subscribe.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("IBrokerSubscribeService");
    }
  }

  private static final class IBrokerSubscribeServiceFileDescriptorSupplier
      extends IBrokerSubscribeServiceBaseDescriptorSupplier {
    IBrokerSubscribeServiceFileDescriptorSupplier() {}
  }

  private static final class IBrokerSubscribeServiceMethodDescriptorSupplier
      extends IBrokerSubscribeServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    IBrokerSubscribeServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (IBrokerSubscribeServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new IBrokerSubscribeServiceFileDescriptorSupplier())
              .addMethod(getSubscribeMethod())
              .build();
        }
      }
    }
    return result;
  }
}
